pub struct AccessCodeServiceClient<T> { /* private fields */ }Expand description
Manages early access codes for organization creation gating. All RPCs require API key authentication (platform-level, not org-scoped).
Implementations
Sourceimpl<T> AccessCodeServiceClient<T>where
T: GrpcService<Body>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
impl<T> AccessCodeServiceClient<T>where
T: GrpcService<Body>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
pub fn new(inner: T) -> Self
pub fn with_origin(inner: T, origin: Uri) -> Self
pub fn with_interceptor<F>(
inner: T,
interceptor: F,
) -> AccessCodeServiceClient<InterceptedService<T, F>>where
F: Interceptor,
T::ResponseBody: Default,
T: Service<Request<Body>, Response = Response<<T as GrpcService<Body>>::ResponseBody>>,
<T as Service<Request<Body>>>::Error: Into<StdError> + Send + Sync,
Sourcepub fn send_compressed(self, encoding: CompressionEncoding) -> Self
pub fn send_compressed(self, encoding: CompressionEncoding) -> Self
Compress requests with the given encoding.
This requires the server to support it otherwise it might respond with an error.
Sourcepub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
Enable decompressing responses.
Sourcepub fn max_decoding_message_size(self, limit: usize) -> Self
pub fn max_decoding_message_size(self, limit: usize) -> Self
Limits the maximum size of a decoded message.
Default: 4MB
Sourcepub fn max_encoding_message_size(self, limit: usize) -> Self
pub fn max_encoding_message_size(self, limit: usize) -> Self
Limits the maximum size of an encoded message.
Default: usize::MAX
Sourcepub async fn generate_access_codes(
&mut self,
request: impl IntoRequest<GenerateAccessCodesRequest>,
) -> Result<Response<GenerateAccessCodesResponse>, Status>
pub async fn generate_access_codes( &mut self, request: impl IntoRequest<GenerateAccessCodesRequest>, ) -> Result<Response<GenerateAccessCodesResponse>, Status>
Generate one or more access codes with an optional label. Authorization: Requires API key auth (service-level).
Sourcepub async fn list_access_codes(
&mut self,
request: impl IntoRequest<ListAccessCodesRequest>,
) -> Result<Response<ListAccessCodesResponse>, Status>
pub async fn list_access_codes( &mut self, request: impl IntoRequest<ListAccessCodesRequest>, ) -> Result<Response<ListAccessCodesResponse>, Status>
List all access codes (active, redeemed, and revoked). Authorization: Requires API key auth (service-level).
Sourcepub async fn revoke_access_code(
&mut self,
request: impl IntoRequest<RevokeAccessCodeRequest>,
) -> Result<Response<RevokeAccessCodeResponse>, Status>
pub async fn revoke_access_code( &mut self, request: impl IntoRequest<RevokeAccessCodeRequest>, ) -> Result<Response<RevokeAccessCodeResponse>, Status>
Revoke an access code. Revoked codes cannot be used for organization creation. Authorization: Requires API key auth (service-level).