pub struct ApiKeyServiceClient<T> { /* private fields */ }Expand description
Manages scoped API keys for programmatic access. All RPCs operate within the caller’s org (extracted from JWT).
Implementations
Sourceimpl<T> ApiKeyServiceClient<T>where
T: GrpcService<Body>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
impl<T> ApiKeyServiceClient<T>where
T: GrpcService<Body>,
T::Error: Into<StdError>,
T::ResponseBody: Body<Data = Bytes> + Send + 'static,
<T::ResponseBody as Body>::Error: Into<StdError> + Send,
pub fn new(inner: T) -> Self
pub fn with_origin(inner: T, origin: Uri) -> Self
pub fn with_interceptor<F>(
inner: T,
interceptor: F,
) -> ApiKeyServiceClient<InterceptedService<T, F>>where
F: Interceptor,
T::ResponseBody: Default,
T: Service<Request<Body>, Response = Response<<T as GrpcService<Body>>::ResponseBody>>,
<T as Service<Request<Body>>>::Error: Into<StdError> + Send + Sync,
Sourcepub fn send_compressed(self, encoding: CompressionEncoding) -> Self
pub fn send_compressed(self, encoding: CompressionEncoding) -> Self
Compress requests with the given encoding.
This requires the server to support it otherwise it might respond with an error.
Sourcepub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
Enable decompressing responses.
Sourcepub fn max_decoding_message_size(self, limit: usize) -> Self
pub fn max_decoding_message_size(self, limit: usize) -> Self
Limits the maximum size of a decoded message.
Default: 4MB
Sourcepub fn max_encoding_message_size(self, limit: usize) -> Self
pub fn max_encoding_message_size(self, limit: usize) -> Self
Limits the maximum size of an encoded message.
Default: usize::MAX
Sourcepub async fn create_api_key(
&mut self,
request: impl IntoRequest<CreateApiKeyRequest>,
) -> Result<Response<CreateApiKeyResponse>, Status>
pub async fn create_api_key( &mut self, request: impl IntoRequest<CreateApiKeyRequest>, ) -> Result<Response<CreateApiKeyResponse>, Status>
Create a new scoped API key with specific permissions. The full secret key is only returned in the response — store it securely. Authorization: Requires PERMISSION_ORG_WRITE.
Sourcepub async fn list_api_keys(
&mut self,
request: impl IntoRequest<ListApiKeysRequest>,
) -> Result<Response<ListApiKeysResponse>, Status>
pub async fn list_api_keys( &mut self, request: impl IntoRequest<ListApiKeysRequest>, ) -> Result<Response<ListApiKeysResponse>, Status>
List all active API keys in the organization (metadata only, no secrets). Authorization: Requires PERMISSION_ORG_READ.
Sourcepub async fn revoke_api_key(
&mut self,
request: impl IntoRequest<RevokeApiKeyRequest>,
) -> Result<Response<RevokeApiKeyResponse>, Status>
pub async fn revoke_api_key( &mut self, request: impl IntoRequest<RevokeApiKeyRequest>, ) -> Result<Response<RevokeApiKeyResponse>, Status>
Revoke an API key. The key becomes immediately unusable. Authorization: Requires PERMISSION_ORG_WRITE.