#[repr(i32)]pub enum AuditExportFormat {
Unspecified = 0,
Csv = 1,
Json = 2,
Parquet = 3,
}Expand description
Format for audit trail export.
Variants
Unspecified = 0
Default value; should not be used explicitly.
Csv = 1
Comma-separated values.
Json = 2
JSON lines format.
Parquet = 3
Apache Parquet columnar format.
Implementations
Sourceimpl AuditExportFormat
impl AuditExportFormat
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.