#[repr(i32)]pub enum ChannelSkipReason {
Unspecified = 0,
OptedOut = 1,
RegionBlocked = 2,
CostCapExceeded = 3,
NoIdentifier = 4,
OrgSuspended = 5,
}Expand description
Reason a dispatch was SKIPPED rather than attempted. Set when status is CHANNEL_EVENT_STATUS_SKIPPED; UNSPECIFIED otherwise.
Variants
Unspecified = 0
OptedOut = 1
RegionBlocked = 2
CostCapExceeded = 3
NoIdentifier = 4
OrgSuspended = 5
Implementations
Sourceimpl ChannelSkipReason
impl ChannelSkipReason
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of ChannelSkipReason.
Sourcepub fn from_i32(value: i32) -> Option<ChannelSkipReason>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<ChannelSkipReason>
Use the TryFrom<i32> implementation instead
Converts an i32 to a ChannelSkipReason, or None if value is not a valid variant.
Sourceimpl ChannelSkipReason
impl ChannelSkipReason
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.