#[repr(i32)]pub enum ChannelStepKind {
Unspecified = 0,
Reminder = 1,
Escalation = 2,
}Expand description
Workflow step kind that triggered the channel dispatch. Different step kinds for the same (campaign, recipient, channel) tuple are treated as distinct dispatch events for idempotency purposes.
Variants
Implementations
Sourceimpl ChannelStepKind
impl ChannelStepKind
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.