#[repr(i32)]pub enum EvidenceCoverage {
Unspecified = 0,
Full = 1,
Sampled = 2,
}Expand description
Whether an evidence source observes the whole population or a sample of it.
Variants
Implementations
Sourceimpl EvidenceCoverage
impl EvidenceCoverage
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of EvidenceCoverage.
Sourcepub fn from_i32(value: i32) -> Option<EvidenceCoverage>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<EvidenceCoverage>
Use the TryFrom<i32> implementation instead
Converts an i32 to a EvidenceCoverage, or None if value is not a valid variant.
Sourceimpl EvidenceCoverage
impl EvidenceCoverage
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.