#[repr(i32)]pub enum HeatmapMode {
Unspecified = 0,
Total = 1,
Median = 2,
}Expand description
Aggregation mode for heatmap data queries.
Variants
Unspecified = 0
Default value; not a valid mode.
Total = 1
Sum of all cohort buckets’ touches per grid cell (default).
Median = 2
Median touch count per grid cell across cohort buckets.
Implementations
Sourceimpl HeatmapMode
impl HeatmapMode
Sourceimpl HeatmapMode
impl HeatmapMode
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.