#[repr(i32)]pub enum IndicatorDirection {
Unspecified = 0,
HigherIsBetter = 1,
LowerIsBetter = 2,
}Expand description
Whether a higher or a lower reading of an indicator is the desired direction.
Variants
Implementations
Sourceimpl IndicatorDirection
impl IndicatorDirection
Sourcepub const fn is_valid(value: i32) -> bool
pub const fn is_valid(value: i32) -> bool
Returns true if value is a variant of IndicatorDirection.
Sourcepub fn from_i32(value: i32) -> Option<IndicatorDirection>
👎Deprecated: Use the TryFrom<i32> implementation instead
pub fn from_i32(value: i32) -> Option<IndicatorDirection>
Use the TryFrom<i32> implementation instead
Converts an i32 to a IndicatorDirection, or None if value is not a valid variant.
Sourceimpl IndicatorDirection
impl IndicatorDirection
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.