#[repr(i32)]pub enum KeyType {
Unspecified = 0,
ApiKey = 1,
ScimToken = 2,
}Expand description
Type of API key, distinguishing platform keys from SCIM provisioning tokens.
Variants
Implementations
Sourceimpl KeyType
impl KeyType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.