#[repr(i32)]pub enum LeverSource {
Unspecified = 0,
Model = 1,
Rules = 2,
}Expand description
How a lever classification was produced.
Variants
Unspecified = 0
Model = 1
Produced by a trained classification model.
Rules = 2
Produced by deterministic rules over campaign metadata.
Implementations
Sourceimpl LeverSource
impl LeverSource
Sourceimpl LeverSource
impl LeverSource
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.