#[repr(i32)]pub enum OrgType {
Unspecified = 0,
Standard = 1,
Sandbox = 2,
Staff = 3,
}Expand description
Classification of an organization’s lifecycle type.
Variants
Unspecified = 0
Standard = 1
Sandbox = 2
Staff = 3
Reserved for platform operations. At most one per deployment, seeded by migration. Cannot be created via CreateOrganization.
Implementations
Sourceimpl OrgType
impl OrgType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.