#[repr(i32)]pub enum TouchEventType {
Unspecified = 0,
Tap = 1,
LongPress = 2,
Scroll = 3,
ActionClick = 4,
}Expand description
Type of touch event captured on the mobile app.
Variants
Unspecified = 0
Default value; not a valid event type.
Tap = 1
A single tap on the screen.
LongPress = 2
A long press (held for 500ms+).
Scroll = 3
A periodic scroll position sample (viewport midpoint every 2s).
ActionClick = 4
The user tapped an action button (e.g. “Acknowledge”).
Implementations
Sourceimpl TouchEventType
impl TouchEventType
Sourcepub fn as_str_name(&self) -> &'static str
pub fn as_str_name(&self) -> &'static str
String value of the enum field names used in the ProtoBuf definition.
The values are not transformed in any way and thus are considered stable (if the ProtoBuf definition does not change) and safe for programmatic use.
Sourcepub fn from_str_name(value: &str) -> Option<Self>
pub fn from_str_name(value: &str) -> Option<Self>
Creates an enum from field names used in the ProtoBuf definition.