pub struct CreateApiKeyRequest {
pub name: String,
pub permissions: Vec<i32>,
pub expires_at: Option<Timestamp>,
pub key_type: i32,
}Expand description
Request to create a new API key.
Fields
name: StringHuman-friendly label. Required, max 200 characters.
permissions: Vec<i32>Permissions to grant. Required, at least one. PERMISSION_UNSPECIFIED values are rejected.
expires_at: Option<Timestamp>Optional expiration time. If omitted, the key does not expire.
key_type: i32Type of key to create. Defaults to KEY_TYPE_API_KEY. SCIM tokens use the “pidgr_scim_” prefix instead of “pidgr_k_”.
Implementations
Sourceimpl CreateApiKeyRequest
impl CreateApiKeyRequest
Sourcepub fn permissions(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<Permission>> ⓘ
pub fn permissions( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<Permission>> ⓘ
Returns an iterator which yields the valid enum values contained in permissions.
Sourcepub fn push_permissions(&mut self, value: Permission)
pub fn push_permissions(&mut self, value: Permission)
Appends the provided enum value to permissions.
Sourcepub fn key_type(&self) -> KeyType
pub fn key_type(&self) -> KeyType
Returns the enum value of key_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_key_type(&mut self, value: KeyType)
pub fn set_key_type(&mut self, value: KeyType)
Sets key_type to the provided enum value.