pub struct CreateRoleRequest {
pub name: String,
pub permissions: Vec<i32>,
}Expand description
Request to create a new role in the caller’s organization.
Fields
name: StringDisplay name for the role (e.g. “Team Lead”). Required. A slug is auto-generated from the name.
permissions: Vec<i32>Initial permission set for the role. PERMISSION_UNSPECIFIED values are rejected.
Implementations
Sourceimpl CreateRoleRequest
impl CreateRoleRequest
Sourcepub fn permissions(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<Permission>>
pub fn permissions( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<Permission>>
Returns an iterator which yields the valid enum values contained in permissions.
Sourcepub fn push_permissions(&mut self, value: Permission)
pub fn push_permissions(&mut self, value: Permission)
Appends the provided enum value to permissions.