pub struct CreateTemplateTranslationRequest {
pub template_id: String,
pub version: i32,
pub locale: String,
pub title: String,
pub body: String,
pub translated_by: String,
pub status: i32,
}Expand description
Request to create a translation for a template.
Fields
template_id: StringID of the template to translate.
version: i32Version of the template to translate.
locale: StringTarget locale.
title: StringTranslated title.
body: StringTranslated body content.
translated_by: StringWho created this translation (“ai:bedrock” or user UUID).
status: i32Initial status (typically DRAFT or AI_TRANSLATED).
Implementations
Sourceimpl CreateTemplateTranslationRequest
impl CreateTemplateTranslationRequest
Sourcepub fn status(&self) -> TranslationStatus
pub fn status(&self) -> TranslationStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: TranslationStatus)
pub fn set_status(&mut self, value: TranslationStatus)
Sets status to the provided enum value.