pub struct DispatchToChannelResponse {
pub dispatch_id: String,
pub status: i32,
pub failure_reason: Option<String>,
}Fields
dispatch_id: StringEchoes back the request’s dispatch_id.
status: i32Terminal outcome of this call.
failure_reason: Option<String>Human-readable failure reason; set only when status is
DISPATCH_STATUS_FAILED.
Implementations
Sourceimpl DispatchToChannelResponse
impl DispatchToChannelResponse
Sourcepub fn status(&self) -> DispatchStatus
pub fn status(&self) -> DispatchStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: DispatchStatus)
pub fn set_status(&mut self, value: DispatchStatus)
Sets status to the provided enum value.
Sourcepub fn failure_reason(&self) -> &str
pub fn failure_reason(&self) -> &str
Returns the value of failure_reason, or the default value if failure_reason is unset.