pub struct GetOrgWebhookConfigResponse {
pub org_id: String,
pub url: String,
pub enabled: bool,
pub has_secret: bool,
pub created_at: Option<Timestamp>,
pub updated_at: Option<Timestamp>,
}Fields
org_id: Stringurl: StringDestination URL Pidgr POSTs notification events to. Empty when no configuration exists.
enabled: boolWhether dispatch via the WEBHOOK channel is enabled for the org.
has_secret: boolWhether a signing secret is currently configured. The secret itself is never returned.
created_at: Option<Timestamp>updated_at: Option<Timestamp>Trait Implementations
Sourceimpl Clone for GetOrgWebhookConfigResponse
impl Clone for GetOrgWebhookConfigResponse
Sourcefn clone(&self) -> GetOrgWebhookConfigResponse
fn clone(&self) -> GetOrgWebhookConfigResponse
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for GetOrgWebhookConfigResponse
impl Debug for GetOrgWebhookConfigResponse
impl Eq for GetOrgWebhookConfigResponse
Sourceimpl Hash for GetOrgWebhookConfigResponse
impl Hash for GetOrgWebhookConfigResponse
Sourceimpl Message for GetOrgWebhookConfigResponse
impl Message for GetOrgWebhookConfigResponse
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.impl StructuralPartialEq for GetOrgWebhookConfigResponse