pub struct GetReachabilityRequest {
pub org_id: String,
pub user_id: String,
pub channel: i32,
}Expand description
Returns the reachability metadata for a single (user, channel) tuple. Returns NOT_FOUND if no row exists.
Fields
org_id: Stringuser_id: Stringchannel: i32Implementations
Sourceimpl GetReachabilityRequest
impl GetReachabilityRequest
Sourcepub fn channel(&self) -> ChannelName
pub fn channel(&self) -> ChannelName
Returns the enum value of channel, or the default if the field is set to an invalid enum value.
Sourcepub fn set_channel(&mut self, value: ChannelName)
pub fn set_channel(&mut self, value: ChannelName)
Sets channel to the provided enum value.