pub struct LinkCampaignToObjectiveRequest {
pub campaign_id: String,
pub objective_id: String,
pub origin: i32,
}Expand description
Request to declare that a campaign serves an objective.
Fields
campaign_id: StringCampaign to link. Required.
objective_id: StringObjective the campaign serves. Required.
origin: i32How the link came to be. Defaults to LINK_ORIGIN_DECLARED when unspecified.
Implementations
Sourceimpl LinkCampaignToObjectiveRequest
impl LinkCampaignToObjectiveRequest
Sourcepub fn origin(&self) -> LinkOrigin
pub fn origin(&self) -> LinkOrigin
Returns the enum value of origin, or the default if the field is set to an invalid enum value.
Sourcepub fn set_origin(&mut self, value: LinkOrigin)
pub fn set_origin(&mut self, value: LinkOrigin)
Sets origin to the provided enum value.