pub struct ListObjectivesRequest {
pub pagination: Option<Pagination>,
pub state: i32,
pub kind: i32,
}Expand description
Request to list the organization’s objectives with pagination.
Fields
pagination: Option<Pagination>Pagination parameters.
state: i32Return only objectives in this state. Unspecified returns every state except OBJECTIVE_STATE_ARCHIVED.
kind: i32Return only entries of this kind. Unspecified returns both kinds.
Implementations
Sourceimpl ListObjectivesRequest
impl ListObjectivesRequest
Sourcepub fn state(&self) -> ObjectiveState
pub fn state(&self) -> ObjectiveState
Returns the enum value of state, or the default if the field is set to an invalid enum value.
Sourcepub fn set_state(&mut self, value: ObjectiveState)
pub fn set_state(&mut self, value: ObjectiveState)
Sets state to the provided enum value.
Sourcepub fn kind(&self) -> ObjectiveKind
pub fn kind(&self) -> ObjectiveKind
Returns the enum value of kind, or the default if the field is set to an invalid enum value.
Sourcepub fn set_kind(&mut self, value: ObjectiveKind)
pub fn set_kind(&mut self, value: ObjectiveKind)
Sets kind to the provided enum value.