pub struct MessageAction {
pub id: String,
pub type: i32,
pub label: String,
}Expand description
An action button attached to a message that a recipient can interact with.
Fields
id: StringUnique identifier for this action within the message.
type: i32The type of action (e.g. ACK).
label: StringDisplay label shown to the recipient (e.g. “Got it”). Constraints: Max length 50 characters.
Implementations
Sourceimpl MessageAction
impl MessageAction
Sourcepub fn type(&self) -> ActionType
pub fn type(&self) -> ActionType
Returns the enum value of type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_type(&mut self, value: ActionType)
pub fn set_type(&mut self, value: ActionType)
Sets type to the provided enum value.