pub struct QueryHeatmapDataRequest {
pub screen_name: String,
pub date_from: Option<Timestamp>,
pub date_to: Option<Timestamp>,
pub campaign_id: String,
pub grid_resolution: f32,
pub mode: i32,
pub event_types: Vec<i32>,
}Expand description
Request to query aggregated heatmap data for a screen.
Fields
screen_name: StringScreen name to query. Constraints: Max length 200 characters.
date_from: Option<Timestamp>Start of the time range filter (inclusive).
date_to: Option<Timestamp>End of the time range filter (inclusive).
campaign_id: StringOptional: filter by campaign ID. Constraints: UUID format (36 characters).
grid_resolution: f32Grid resolution for coordinate rounding. Default: 0.02 (50×50 grid). Constraints: Range 0.005 to 0.1.
mode: i32Aggregation mode (TOTAL or MEDIAN).
event_types: Vec<i32>Optional: filter by event types. Empty list means all types.
Implementations
Sourceimpl QueryHeatmapDataRequest
impl QueryHeatmapDataRequest
Sourcepub fn mode(&self) -> HeatmapMode
pub fn mode(&self) -> HeatmapMode
Returns the enum value of mode, or the default if the field is set to an invalid enum value.
Sourcepub fn set_mode(&mut self, value: HeatmapMode)
pub fn set_mode(&mut self, value: HeatmapMode)
Sets mode to the provided enum value.
Sourcepub fn event_types(
&self,
) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<TouchEventType>>
pub fn event_types( &self, ) -> FilterMap<Cloned<Iter<'_, i32>>, fn(i32) -> Option<TouchEventType>>
Returns an iterator which yields the valid enum values contained in event_types.
Sourcepub fn push_event_types(&mut self, value: TouchEventType)
pub fn push_event_types(&mut self, value: TouchEventType)
Appends the provided enum value to event_types.