pub struct SendNotificationConfig {
pub type: String,
pub template_id: String,
pub template_version: i32,
pub action_label: String,
pub action_type: i32,
pub custom_variables: HashMap<String, String>,
}Expand description
Configuration for a step that sends the initial push notification.
Fields
type: StringNotification delivery type (e.g. “push”). Constraints: Accepted values: “push”. Max length 50 characters.
template_id: StringID of the template to use for this step’s notification. Empty falls back to campaign-level template_id. Constraints: Max length 36 characters (UUID).
template_version: i32Pinned template version for this step. 0 falls back to campaign-level template_version.
action_label: StringDisplay label for the action button (e.g. “Acknowledge”, “Got it”). Constraints: Max length 50 characters.
action_type: i32Action type for this step’s message button.
custom_variables: HashMap<String, String>Values for custom-sourced template variables specific to this step. Constraints: Max 100 entries. Key max length 100 characters, value max length 10000 characters.
Implementations
Sourceimpl SendNotificationConfig
impl SendNotificationConfig
Sourcepub fn action_type(&self) -> ActionType
pub fn action_type(&self) -> ActionType
Returns the enum value of action_type, or the default if the field is set to an invalid enum value.
Sourcepub fn set_action_type(&mut self, value: ActionType)
pub fn set_action_type(&mut self, value: ActionType)
Sets action_type to the provided enum value.