pub struct SetCostCapPolicyRequest {
pub org_id: String,
pub channel: i32,
pub cap_micros: i64,
}Expand description
Admin-only upsert of the cap for the current calendar-month period. Future periods inherit the most recent SetCostCapPolicy value until the next call.
Fields
org_id: Stringchannel: i32cap_micros: i64Implementations
Sourceimpl SetCostCapPolicyRequest
impl SetCostCapPolicyRequest
Sourcepub fn channel(&self) -> ChannelName
pub fn channel(&self) -> ChannelName
Returns the enum value of channel, or the default if the field is set to an invalid enum value.
Sourcepub fn set_channel(&mut self, value: ChannelName)
pub fn set_channel(&mut self, value: ChannelName)
Sets channel to the provided enum value.