pub struct SetRegionPolicyRequest {
pub org_id: String,
pub channel: i32,
pub allowed_regions: Vec<String>,
}Expand description
Admin-only upsert. Empty allowed_regions clears the policy.
Fields
org_id: Stringchannel: i32allowed_regions: Vec<String>AWS region identifiers (e.g. “eu-west-1”). Empty list == “no policy.”
Implementations
Sourceimpl SetRegionPolicyRequest
impl SetRegionPolicyRequest
Sourcepub fn channel(&self) -> ChannelName
pub fn channel(&self) -> ChannelName
Returns the enum value of channel, or the default if the field is set to an invalid enum value.
Sourcepub fn set_channel(&mut self, value: ChannelName)
pub fn set_channel(&mut self, value: ChannelName)
Sets channel to the provided enum value.