pub struct UpdateOrganizationRequest {
pub name: String,
pub default_workflow: Option<WorkflowDefinition>,
pub industry: i32,
pub company_size: i32,
pub default_locale: String,
}Expand description
Request to update organization settings.
Fields
name: StringNew organization name. Empty string leaves unchanged. Constraints: Max length 200 characters.
default_workflow: Option<WorkflowDefinition>New default workflow definition. Null leaves unchanged.
industry: i32New industry vertical. UNSPECIFIED leaves unchanged.
company_size: i32New employee headcount range. UNSPECIFIED leaves unchanged.
default_locale: StringNew default language for new users. Empty string leaves unchanged. Valid values: en, es, pt-BR, zh, ja.
Implementations
Sourceimpl UpdateOrganizationRequest
impl UpdateOrganizationRequest
Sourcepub fn industry(&self) -> Industry
pub fn industry(&self) -> Industry
Returns the enum value of industry, or the default if the field is set to an invalid enum value.
Sourcepub fn set_industry(&mut self, value: Industry)
pub fn set_industry(&mut self, value: Industry)
Sets industry to the provided enum value.
Sourcepub fn company_size(&self) -> CompanySize
pub fn company_size(&self) -> CompanySize
Returns the enum value of company_size, or the default if the field is set to an invalid enum value.
Sourcepub fn set_company_size(&mut self, value: CompanySize)
pub fn set_company_size(&mut self, value: CompanySize)
Sets company_size to the provided enum value.